@@ -20,6 +20,7 @@
 
 ActivityTag::ActivityTag()
 {
+	comments=QString("");
 }
 
 ActivityTag::~ActivityTag()
@@ -30,11 +31,23 @@ QString ActivityTag::getXmlDescription()
 {
 	QString s="<Activity_Tag>\n";
 	s+="	<Name>"+protect(this->name)+"</Name>\n";
+	s+="	<Comments>"+protect(comments)+"</Comments>\n";
 	s+="</Activity_Tag>\n";
 
 	return s;
 }
 
+QString ActivityTag::getDescription()
+{
+	QString s=tr("N:%1", "The name of the activity tag").arg(name);
+	
+	QString end=QString("");
+	if(!comments.isEmpty())
+		end=", "+tr("C: %1", "Comments").arg(comments);
+	
+	return s+end;
+}
+
 QString ActivityTag::getDetailedDescription()
 {
 	QString s=tr("Activity tag");
@@ -42,6 +55,12 @@ QString ActivityTag::getDetailedDescription()
 	s+=tr("Name=%1", "The name of the activity tag").arg(this->name);
 	s+="\n";
 
+	//Has comments?
+	if(!comments.isEmpty()){
+		s+=tr("Comments=%1").arg(comments);
+		s+="\n";
+	}
+
 	return s;
 }
 
