@@ -8,41 +8,40 @@
 
 /***************************************************************************
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   This program is free software: you can redistribute it and/or modify  *
+ *   it under the terms of the GNU Affero General Public License as        *
+ *   published by the Free Software Foundation, either version 3 of the    *
+ *   License, or (at your option) any later version.                       *
  *                                                                         *
  ***************************************************************************/
 
 #ifndef ADDCONSTRAINTACTIVITYPREFERREDROOMFORM_H
 #define ADDCONSTRAINTACTIVITYPREFERREDROOMFORM_H
 
-#include "addconstraintactivitypreferredroomform_template.h"
+#include "ui_addconstraintactivitypreferredroomform_template.h"
 #include "timetable_defs.h"
 #include "timetable.h"
 #include "fet.h"
-//#include "fetmainform.h"
 
-#include <q3combobox.h>
-#include <q3listbox.h>
-#include <qmessagebox.h>
-#include <q3groupbox.h>
-#include <qspinbox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <q3textedit.h>
-
-class AddConstraintActivityPreferredRoomForm : public AddConstraintActivityPreferredRoomForm_template  {
+class AddConstraintActivityPreferredRoomForm : public QDialog, Ui::AddConstraintActivityPreferredRoomForm_template  {
+	Q_OBJECT
 public:
-	AddConstraintActivityPreferredRoomForm();
+	AddConstraintActivityPreferredRoomForm(QWidget* parent);
 	~AddConstraintActivityPreferredRoomForm();
 
 	void updateActivitiesComboBox();
 	void updateRoomsComboBox();
 
+	bool filterOk(Activity* a);
+
+public slots:
 	void addConstraint();
+
+	void filterChanged();
+	
+private:
+	//the id's of the activities listed in the activities combo
+	QList<int> activitiesList;
 };
 
 #endif
