@@ -151,6 +151,7 @@ public slots:
 	void on_dataSubgroupsAction_triggered();
 	void on_dataStudentsStatisticsAction_triggered();
 	void on_dataActivitiesRoomsStatisticsAction_triggered();
+	void on_dataTeachersSubjectsQualificationsStatisticsAction_triggered();
 	void on_dataHelpOnStatisticsAction_triggered();
 	
 	void on_helpSettingsAction_triggered();
@@ -160,24 +161,7 @@ public slots:
 	void on_settingsShowShortcutsOnMainWindowAction_toggled();
 	void on_settingsShowToolTipsForConstraintsWithTablesAction_toggled();
 	
-	///write timetables options
-	void on_enableConflictsTimetableAction_toggled();
-
-	void on_enableStatisticsTimetablesAction_toggled();
-	void on_enableXmlTimetablesAction_toggled();
-	void on_enableDaysHorizontalTimetablesAction_toggled();
-	void on_enableDaysVerticalTimetablesAction_toggled();
-	void on_enableTimeHorizontalTimetablesAction_toggled();
-	void on_enableTimeVerticalTimetablesAction_toggled();
-
-	void on_enableSubgroupsTimetablesAction_toggled();
-	void on_enableGroupsTimetablesAction_toggled();
-	void on_enableYearsTimetablesAction_toggled();
-	void on_enableTeachersTimetablesAction_toggled();
-	void on_enableTeachersFreePeriodsTimetablesAction_toggled();
-	void on_enableRoomsTimetablesAction_toggled();
-	void on_enableSubjectsTimetablesAction_toggled();
-	void on_enableActivitiesTimetablesAction_toggled();
+	void on_timetablesToWriteOnDiskAction_triggered();
 	///
 
 	//////confirmations
@@ -372,6 +356,8 @@ public slots:
 
 	void on_settingsTimetableHtmlLevelAction_triggered();
 	void on_settingsPrintActivityTagsAction_toggled();
+	void on_settingsPrintDetailedTimetablesAction_toggled();
+	void on_settingsPrintDetailedTeachersFreePeriodsTimetablesAction_toggled();
 	void on_settingsPrintNotAvailableSlotsAction_toggled();
 	void on_settingsPrintBreakSlotsAction_toggled();
 
