@@ -745,7 +745,7 @@ void SplitYearForm::help()
 	s+="\n";
 	s+=tr("Maybe an alternative to dividing a year into many categories/subgroups would be to enter individual students as FET subgroups and add into"
 		" each group the corresponding subgroups. But this is hard to do from the FET interface - maybe a solution would be to use an automatic"
-		" tool to convert your instition data into a file in .fet format.");
+		" tool to convert your institution data into a file in .fet format.");
 	s+=" ";
 	s+=tr("Or you might use the FET feature to import students sets from comma separated values (CSV) files.");
 	s+=" ";
